@@ -35,7 +35,7 @@
 #include <bits/os_defines.h>
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20050225
+#define __GLIBCXX__ 20050401
 
 // Allow use of "export template." This is currently not a feature
 // that g++ supports.
@@ -176,7 +176,7 @@ namespace std
 #define _GLIBCXX_HAVE_SIGSETJMP 1
 
 // Define if mbstate_t exists in wchar.h.
-/* #undef _GLIBCXX_HAVE_MBSTATE_T */
+#define _GLIBCXX_HAVE_MBSTATE_T 1
 
 // Define if you have the modff function.
 #define _GLIBCXX_HAVE_MODFF 1
@@ -291,7 +291,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_ATANL */
 
 /* Define to 1 if you have the `btowc' function. */
-/* #undef _GLIBCXX_HAVE_BTOWC */
+#define _GLIBCXX_HAVE_BTOWC 1
 
 /* Define to 1 if you have the `ceilf' function. */
 #define _GLIBCXX_HAVE_CEILF 1
@@ -336,10 +336,10 @@ namespace std
 /* #undef _GLIBCXX_HAVE_FABSL */
 
 /* Define to 1 if you have the `fgetwc' function. */
-/* #undef _GLIBCXX_HAVE_FGETWC */
+#define _GLIBCXX_HAVE_FGETWC 1
 
 /* Define to 1 if you have the `fgetws' function. */
-/* #undef _GLIBCXX_HAVE_FGETWS */
+#define _GLIBCXX_HAVE_FGETWS 1
 
 /* Define to 1 if you have the `finite' function. */
 #define _GLIBCXX_HAVE_FINITE 1
@@ -369,10 +369,10 @@ namespace std
 /* #undef _GLIBCXX_HAVE_FPCLASS */
 
 /* Define to 1 if you have the `fputwc' function. */
-/* #undef _GLIBCXX_HAVE_FPUTWC */
+#define _GLIBCXX_HAVE_FPUTWC 1
 
 /* Define to 1 if you have the `fputws' function. */
-/* #undef _GLIBCXX_HAVE_FPUTWS */
+#define _GLIBCXX_HAVE_FPUTWS 1
 
 /* Define to 1 if you have the <fp.h> header file. */
 /* #undef _GLIBCXX_HAVE_FP_H */
@@ -384,7 +384,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_FREXPL */
 
 /* Define to 1 if you have the `fwide' function. */
-/* #undef _GLIBCXX_HAVE_FWIDE */
+#define _GLIBCXX_HAVE_FWIDE 1
 
 /* Define to 1 if you have the `fwprintf' function. */
 /* #undef _GLIBCXX_HAVE_FWPRINTF */
@@ -399,10 +399,10 @@ namespace std
 #define _GLIBCXX_HAVE_GETPAGESIZE 1
 
 /* Define to 1 if you have the `getwc' function. */
-/* #undef _GLIBCXX_HAVE_GETWC */
+#define _GLIBCXX_HAVE_GETWC 1
 
 /* Define to 1 if you have the `getwchar' function. */
-/* #undef _GLIBCXX_HAVE_GETWCHAR */
+#define _GLIBCXX_HAVE_GETWCHAR 1
 
 /* Define to 1 if you have the `hypot' function. */
 #define _GLIBCXX_HAVE_HYPOT 1
@@ -447,7 +447,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_ISNANL */
 
 /* Define to 1 if you have the `iswblank' function. */
-/* #undef _GLIBCXX_HAVE_ISWBLANK */
+#define _GLIBCXX_HAVE_ISWBLANK 1
 
 /* Define to 1 if you have the `ldexpf' function. */
 #define _GLIBCXX_HAVE_LDEXPF 1
@@ -498,16 +498,16 @@ namespace std
 #define _GLIBCXX_HAVE_MACHINE_PARAM_H 1
 
 /* Define to 1 if you have the `mbrlen' function. */
-/* #undef _GLIBCXX_HAVE_MBRLEN */
+#define _GLIBCXX_HAVE_MBRLEN 1
 
 /* Define to 1 if you have the `mbrtowc' function. */
-/* #undef _GLIBCXX_HAVE_MBRTOWC */
+#define _GLIBCXX_HAVE_MBRTOWC 1
 
 /* Define to 1 if you have the `mbsinit' function. */
-/* #undef _GLIBCXX_HAVE_MBSINIT */
+#define _GLIBCXX_HAVE_MBSINIT 1
 
 /* Define to 1 if you have the `mbsrtowcs' function. */
-/* #undef _GLIBCXX_HAVE_MBSRTOWCS */
+#define _GLIBCXX_HAVE_MBSRTOWCS 1
 
 /* Define to 1 if you have the <memory.h> header file. */
 #define _GLIBCXX_HAVE_MEMORY_H 1
@@ -525,7 +525,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_NAN_H */
 
 /* Define to 1 if you have the `nl_langinfo' function. */
-/* #undef _GLIBCXX_HAVE_NL_LANGINFO */
+#define _GLIBCXX_HAVE_NL_LANGINFO 1
 
 /* Define to 1 if you have the `powf' function. */
 #define _GLIBCXX_HAVE_POWF 1
@@ -534,10 +534,10 @@ namespace std
 /* #undef _GLIBCXX_HAVE_POWL */
 
 /* Define to 1 if you have the `putwc' function. */
-/* #undef _GLIBCXX_HAVE_PUTWC */
+#define _GLIBCXX_HAVE_PUTWC 1
 
 /* Define to 1 if you have the `putwchar' function. */
-/* #undef _GLIBCXX_HAVE_PUTWCHAR */
+#define _GLIBCXX_HAVE_PUTWCHAR 1
 
 /* Define to 1 if you have the `qfpclass' function. */
 /* #undef _GLIBCXX_HAVE_QFPCLASS */
@@ -642,7 +642,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_TANL */
 
 /* Define to 1 if you have the `ungetwc' function. */
-/* #undef _GLIBCXX_HAVE_UNGETWC */
+#define _GLIBCXX_HAVE_UNGETWC 1
 
 /* Define to 1 if you have the <unistd.h> header file. */
 #define _GLIBCXX_HAVE_UNISTD_H 1
@@ -666,97 +666,97 @@ namespace std
 /* #undef _GLIBCXX_HAVE_VWSCANF */
 
 /* Define to 1 if you have the <wchar.h> header file. */
-/* #undef _GLIBCXX_HAVE_WCHAR_H */
+#define _GLIBCXX_HAVE_WCHAR_H 1
 
 /* Define to 1 if you have the `wcrtomb' function. */
-/* #undef _GLIBCXX_HAVE_WCRTOMB */
+#define _GLIBCXX_HAVE_WCRTOMB 1
 
 /* Define to 1 if you have the `wcscat' function. */
-/* #undef _GLIBCXX_HAVE_WCSCAT */
+#define _GLIBCXX_HAVE_WCSCAT 1
 
 /* Define to 1 if you have the `wcschr' function. */
-/* #undef _GLIBCXX_HAVE_WCSCHR */
+#define _GLIBCXX_HAVE_WCSCHR 1
 
 /* Define to 1 if you have the `wcscmp' function. */
-/* #undef _GLIBCXX_HAVE_WCSCMP */
+#define _GLIBCXX_HAVE_WCSCMP 1
 
 /* Define to 1 if you have the `wcscoll' function. */
-/* #undef _GLIBCXX_HAVE_WCSCOLL */
+#define _GLIBCXX_HAVE_WCSCOLL 1
 
 /* Define to 1 if you have the `wcscpy' function. */
-/* #undef _GLIBCXX_HAVE_WCSCPY */
+#define _GLIBCXX_HAVE_WCSCPY 1
 
 /* Define to 1 if you have the `wcscspn' function. */
-/* #undef _GLIBCXX_HAVE_WCSCSPN */
+#define _GLIBCXX_HAVE_WCSCSPN 1
 
 /* Define to 1 if you have the `wcsftime' function. */
 /* #undef _GLIBCXX_HAVE_WCSFTIME */
 
 /* Define to 1 if you have the `wcslen' function. */
-/* #undef _GLIBCXX_HAVE_WCSLEN */
+#define _GLIBCXX_HAVE_WCSLEN 1
 
 /* Define to 1 if you have the `wcsncat' function. */
-/* #undef _GLIBCXX_HAVE_WCSNCAT */
+#define _GLIBCXX_HAVE_WCSNCAT 1
 
 /* Define to 1 if you have the `wcsncmp' function. */
-/* #undef _GLIBCXX_HAVE_WCSNCMP */
+#define _GLIBCXX_HAVE_WCSNCMP 1
 
 /* Define to 1 if you have the `wcsncpy' function. */
-/* #undef _GLIBCXX_HAVE_WCSNCPY */
+#define _GLIBCXX_HAVE_WCSNCPY 1
 
 /* Define to 1 if you have the `wcspbrk' function. */
-/* #undef _GLIBCXX_HAVE_WCSPBRK */
+#define _GLIBCXX_HAVE_WCSPBRK 1
 
 /* Define to 1 if you have the `wcsrchr' function. */
-/* #undef _GLIBCXX_HAVE_WCSRCHR */
+#define _GLIBCXX_HAVE_WCSRCHR 1
 
 /* Define to 1 if you have the `wcsrtombs' function. */
-/* #undef _GLIBCXX_HAVE_WCSRTOMBS */
+#define _GLIBCXX_HAVE_WCSRTOMBS 1
 
 /* Define to 1 if you have the `wcsspn' function. */
-/* #undef _GLIBCXX_HAVE_WCSSPN */
+#define _GLIBCXX_HAVE_WCSSPN 1
 
 /* Define to 1 if you have the `wcsstr' function. */
-/* #undef _GLIBCXX_HAVE_WCSSTR */
+#define _GLIBCXX_HAVE_WCSSTR 1
 
 /* Define to 1 if you have the `wcstod' function. */
-/* #undef _GLIBCXX_HAVE_WCSTOD */
+#define _GLIBCXX_HAVE_WCSTOD 1
 
 /* Define to 1 if you have the `wcstof' function. */
 /* #undef _GLIBCXX_HAVE_WCSTOF */
 
 /* Define to 1 if you have the `wcstok' function. */
-/* #undef _GLIBCXX_HAVE_WCSTOK */
+#define _GLIBCXX_HAVE_WCSTOK 1
 
 /* Define to 1 if you have the `wcstol' function. */
-/* #undef _GLIBCXX_HAVE_WCSTOL */
+#define _GLIBCXX_HAVE_WCSTOL 1
 
 /* Define to 1 if you have the `wcstoul' function. */
-/* #undef _GLIBCXX_HAVE_WCSTOUL */
+#define _GLIBCXX_HAVE_WCSTOUL 1
 
 /* Define to 1 if you have the `wcsxfrm' function. */
-/* #undef _GLIBCXX_HAVE_WCSXFRM */
+#define _GLIBCXX_HAVE_WCSXFRM 1
 
 /* Define to 1 if you have the `wctob' function. */
-/* #undef _GLIBCXX_HAVE_WCTOB */
+#define _GLIBCXX_HAVE_WCTOB 1
 
 /* Define to 1 if you have the <wctype.h> header file. */
-/* #undef _GLIBCXX_HAVE_WCTYPE_H */
+#define _GLIBCXX_HAVE_WCTYPE_H 1
 
 /* Define to 1 if you have the `wmemchr' function. */
-/* #undef _GLIBCXX_HAVE_WMEMCHR */
+#define _GLIBCXX_HAVE_WMEMCHR 1
 
 /* Define to 1 if you have the `wmemcmp' function. */
-/* #undef _GLIBCXX_HAVE_WMEMCMP */
+#define _GLIBCXX_HAVE_WMEMCMP 1
 
 /* Define to 1 if you have the `wmemcpy' function. */
-/* #undef _GLIBCXX_HAVE_WMEMCPY */
+#define _GLIBCXX_HAVE_WMEMCPY 1
 
 /* Define to 1 if you have the `wmemmove' function. */
-/* #undef _GLIBCXX_HAVE_WMEMMOVE */
+#define _GLIBCXX_HAVE_WMEMMOVE 1
 
 /* Define to 1 if you have the `wmemset' function. */
-/* #undef _GLIBCXX_HAVE_WMEMSET */
+#define _GLIBCXX_HAVE_WMEMSET 1
 
 /* Define to 1 if you have the `wprintf' function. */
 /* #undef _GLIBCXX_HAVE_WPRINTF */
